@@ -13,7 +13,7 @@ use AnyEvent::WebSocket::Connection;
 use PerlX::Maybe qw( maybe provided );
 
 # ABSTRACT: WebSocket client for AnyEvent
-our $VERSION = '0.40_03'; # TRIAL VERSION
+our $VERSION = '0.42_01'; # TRIAL VERSION
 $VERSION = eval $VERSION;
 
 
@@ -186,7 +186,7 @@ AnyEvent::WebSocket::Client - WebSocket client for AnyEvent
 
 =head1 VERSION
 
-version 0.40_03
+version 0.42_01
 
 =head1 SYNOPSIS
 
@@ -420,11 +420,13 @@ Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
 Contributors:
 
-Toshio Ito
+Toshio Ito (debug-ito, TOSHIOITO)
 
-José Joaquín Atria
+José Joaquín Atria (JJATRIA)
 
-Kivanc Yazan
+Kivanc Yazan (KYZN)
+
+Yanick Champoux (YANICK)
 
 =head1 COPYRIGHT AND LICENSE
 
