@@ -6,7 +6,7 @@ use Moo;
 use Encode ();
 
 # ABSTRACT: WebSocket message for AnyEvent
-our $VERSION = '0.40_03'; # TRIAL VERSION
+our $VERSION = '0.42_01'; # TRIAL VERSION
 $VERSION = eval $VERSION;
 
 
@@ -40,7 +40,7 @@ AnyEvent::WebSocket::Message - WebSocket message for AnyEvent
 
 =head1 VERSION
 
-version 0.40_03
+version 0.42_01
 
 =head1 SYNOPSIS
 
@@ -145,11 +145,13 @@ Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
 Contributors:
 
-Toshio Ito
+Toshio Ito (debug-ito, TOSHIOITO)
 
-José Joaquín Atria
+José Joaquín Atria (JJATRIA)
 
-Kivanc Yazan
+Kivanc Yazan (KYZN)
+
+Yanick Champoux (YANICK)
 
 =head1 COPYRIGHT AND LICENSE
 
